@@ -33,8 +33,10 @@
 KSGRDIface::KSGRDIface(QObject *parent, const QVariantList &args)
     : SensorPlugin(parent, args)
 {
+    KSGRD::SensorMgr = new KSGRD::SensorManager(this);
+
     auto registerSubsystem = [this](const QString &id) {
-        m_subsystems[id] = new SensorContainer(id, id, this); // FIXME name resolve
+        m_subsystems[id] = new SensorContainer(id, KSGRD::SensorMgr->translateSensorPath(id), this);
     };
     registerSubsystem("acpi");
     registerSubsystem("cpu");
@@ -44,8 +46,8 @@ KSGRDIface::KSGRDIface(QObject *parent, const QVariantList &args)
     registerSubsystem("network");
     registerSubsystem("partitions");
     registerSubsystem("uptime");
+    registerSubsystem("system");
 
-    KSGRD::SensorMgr = new KSGRD::SensorManager(this);
     KSGRD::SensorMgr->engage(QStringLiteral("localhost"), QLatin1String(""), QStringLiteral("ksysguardd"));
     connect(KSGRD::SensorMgr, &KSGRD::SensorManager::update, this, &KSGRDIface::updateMonitorsList);
     updateMonitorsList();
@@ -134,7 +136,8 @@ void KSGRDIface::onSensorMetaDataRetrieved(int id, const QList<QByteArray> &answ
     }
     auto sensorObject = subsystem->object(objectId);
     if (!sensorObject) {
-        sensorObject = new SensorObject(objectId, objectId, subsystem); // FIXME i18n name for object id?
+        auto name = KSGRD::SensorMgr->translateSensorPath(objectId);
+        sensorObject = new SensorObject(objectId, name, subsystem);
     }
 
     auto sensor = m_sensors.value(key, nullptr);
@@ -175,6 +178,13 @@ void KSGRDIface::onSensorListRetrieved(const QList<QByteArray> &answer)
     QSet<QString> sensors;
     int count = 0;
 
+    // A list of data types not currently supported
+    static const QStringList excludedTypes = {
+        QStringLiteral("logfile"),
+        QStringLiteral("listview"),
+        QStringLiteral("table")
+    };
+
     for (const QByteArray &sens : answer) {
         const QString sensStr { QString::fromUtf8(sens) };
         const QVector<QStringRef> newSensorInfo = sensStr.splitRef('\t');
@@ -182,8 +192,8 @@ void KSGRDIface::onSensorListRetrieved(const QList<QByteArray> &answer)
             continue;
         }
         auto type = newSensorInfo.at(1);
-        if (type == QLatin1String("logfile")) {
-            continue; // logfile data type not currently supported
+        if (excludedTypes.contains(type)) {
+            continue;
         }
 
         const QString newSensor = newSensorInfo[0].toString();
@@ -369,7 +379,7 @@ void KSGRDIface::addAggregateSensors()
     availableLevel->setDescription(i18nc("@info", "Percentage of available memory."));
 
     PercentageSensor *allocatedLevel = new PercentageSensor(memPhysical, "allocatedlevel", i18nc("@title", "Allocated Memory Percentage"));
-    allocatedLevel->setShortName(i18nc("@title Allocated Memory Percentage", "Used"));
+    allocatedLevel->setShortName(i18nc("@title Allocated Memory Percentage", "Allocated"));
     allocatedLevel->setBaseSensor(memPhysical->sensor("allocated"));
     allocatedLevel->setDescription(i18nc("@info", "Percentage of allocated memory."));
 }
